@@ -28,15 +28,17 @@
 
 #include <KIconLoader>
 #include <KIO/DeleteJob>
-#include <KIO/NetAccess>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KDialog>
-#include <KStandardDirs>
+#include <QDialog>
+
 
 #include <QFile>
+#include <QDir>
 #include <QDomElement>
+#include <QStandardPaths>
+#include <KConfigGroup>
 
 /**
 * @return Hex value from a base64 value
@@ -219,7 +221,11 @@ bool MetalinkHttp::metalinkHttpInit()
 
         //Add OpenPGP signatures
         if (m_signatureUrl != QUrl()) {
-            Download *signat_download = new Download(m_signatureUrl, QString(KStandardDirs::locateLocal("appdata", "metalinks/") + m_source.fileName()));
+            // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
+            if (!QFileInfo::exists(QStandardPaths::writableLocation(QStandardPaths::DataLocation))) {
+                QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
+            }
+            Download *signat_download = new Download(m_signatureUrl, QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/metalinks/") + m_source.fileName());
             connect(signat_download, SIGNAL(finishedSuccessfully(QUrl,QByteArray)), SLOT(setSignature(QUrl,QByteArray)));
         }
         m_dataSourceFactory[dataFactory->dest()] = dataFactory;
